@@ -1,17 +1,16 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+"""Test runner for tmuxp project. ``$ ./run_tests.py --help`` for more."""
 
 from __future__ import absolute_import, division, print_function, with_statement
 
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:  # Python 2.7
+    import unittest
 import sys
 import os
-import subprocess
 import argparse
-import tmuxp.testsuite
-from tmuxp.util import tmux
-
-t = tmuxp.testsuite.t
 
 tmux_path = sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
 if tmux_path not in sys.path:
@@ -19,10 +18,9 @@ if tmux_path not in sys.path:
 
 
 def main(verbosity=2, failfast=False):
+    """Run TestSuite in new tmux session. Exit with code 0 if success."""
 
-    session_name = 'tmuxp'
-    t.tmux('new-session', '-d', '-s', session_name)
-    suites = unittest.TestLoader().discover('tmuxp.testsuite', pattern="*.py")
+    suites = unittest.TestLoader().discover('tmuxp.testsuite', pattern="test_*.py")
     result = unittest.TextTestRunner(
         verbosity=verbosity, failfast=failfast).run(suites)
     if result.wasSuccessful():
@@ -40,20 +38,6 @@ if __name__ == '__main__':
         ''',
         formatter_class=argparse.RawTextHelpFormatter
     )
-    parser.add_argument(
-        '--visual',
-        action='store_true',
-        help='''\
-        Run the session builder testsuite in visual mode. requires having
-        tmux client in a second terminal open with:
-
-        Terminal 1:
-            $ tmux -L tmuxp_test
-
-        Terminal 2:
-            $ ./run_tests.py --visual
-        '''
-    )
     parser.add_argument(
         '--tests',
         nargs='*',
@@ -100,18 +84,6 @@ if __name__ == '__main__':
 
     if 'help' in args:
         parser.print_help()
-    elif 'visual' in args and args.visual:
-        # todo, we can have this test build, and on completion, take the user
-        # to the new session with os.exec and attach the session.
-        loader = unittest.TestLoader()
-        suites = loader.loadTestsFromName('tmuxp.testsuite.test_builder')
-        result = unittest.TextTestRunner(
-            verbosity=verbosity, failfast=args.failfast).run(suites)
-
-        if result.wasSuccessful():
-            sys.exit(0)
-        else:
-            sys.exit(1)
     if args.tests and len(args.tests) > int(0):
         for arg in args.tests:
             if not arg.startswith('tmuxp.testsuite'):
