@@ -8,9 +8,10 @@ tmuxp
 :license: BSD, see LICENSE for details
 
 """
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
-
-from __future__ import absolute_import, division, print_function, with_statement
+__version__ = '0.1.0'
 
 from .session import Session
 from .server import Server
@@ -18,7 +19,3 @@ from .window import Window
 from .pane import Pane
 from .workspacebuilder import WorkspaceBuilder
 from . import config, util, cli
-
-import logging
-
-__version__ = '0.0.44a'
