@@ -8,12 +8,15 @@ tmuxp.config
 :license: BSD, see LICENSE for details
 
 """
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
-from __future__ import absolute_import, division, print_function, with_statement
 import os
+import copy
 import logging
+
 from . import exc
-from .util import basestring
+from ._compat import string_types
 
 logger = logging.getLogger(__name__)
 
@@ -40,7 +43,9 @@ def validate_schema(sconf):
 
         if not 'panes' in window:
             raise exc.ConfigError(
-                'config window %s requires list of panes' % window['window_name'])
+                'config window %s requires list of panes' %
+                window['window_name']
+            )
 
     return True
 
@@ -57,11 +62,14 @@ def is_config_file(filename, extensions=['.yml', '.yaml', '.json']):
     """
 
     extensions = [extensions] if isinstance(
-        extensions, basestring) else extensions
+        extensions, string_types) else extensions
     return any(filename.endswith(e) for e in extensions)
 
 
-def in_dir(config_dir=os.path.expanduser('~/.tmuxp'), extensions=['.yml', '.yaml', '.json']):
+def in_dir(
+    config_dir=os.path.expanduser('~/.tmuxp'),
+    extensions=['.yml', '.yaml', '.json']
+):
     """Return a list of configs in ``config_dir``.
 
     :param config_dir: directory to search
@@ -74,7 +82,8 @@ def in_dir(config_dir=os.path.expanduser('~/.tmuxp'), extensions=['.yml', '.yaml
     configs = []
 
     for filename in os.listdir(config_dir):
-        if is_config_file(filename, extensions) and not filename.startswith('.'):
+        if is_config_file(filename, extensions) and \
+           not filename.startswith('.'):
             configs.append(filename)
 
     return configs
@@ -106,12 +115,20 @@ def inline(sconf):
 
     """
 
-    if ('shell_command' in sconf and isinstance(sconf['shell_command'], list) and len(sconf['shell_command']) == 1):
+    if (
+        'shell_command' in sconf and
+        isinstance(sconf['shell_command'], list) and
+        len(sconf['shell_command']) == 1
+    ):
         sconf['shell_command'] = sconf['shell_command'][0]
 
         if len(sconf.keys()) == int(1):
             sconf = sconf['shell_command']
-    if ('shell_command_before' in sconf and isinstance(sconf['shell_command_before'], list) and len(sconf['shell_command_before']) == 1):
+    if (
+        'shell_command_before' in sconf and
+        isinstance(sconf['shell_command_before'], list) and
+        len(sconf['shell_command_before']) == 1
+    ):
         sconf['shell_command_before'] = sconf['shell_command_before'][0]
 
     # recurse into window and pane config items
@@ -153,22 +170,24 @@ def expand(sconf, cwd=None):
     if not cwd:
         cwd = os.getcwd()
 
-
     # Any config section, session, window, pane that can contain the
     # 'shell_command' value
     if 'start_directory' in sconf:
-        if any(sconf['start_directory'].startswith(a) for a in ['.', './']):
-            sconf['start_directory'] = os.path.normpath(os.path.join(cwd, sconf['start_directory']))
-        elif any(sconf['start_directory'] == a for a in ['.', './']):
-            sconf['start_directory'] = os.path.normpath(os.path.join(cwd, sconf['start_directory']))
+        start_path = sconf['start_directory']
+        if any(start_path.startswith(a) for a in ['.', './']):
+            start_path = os.path.normpath(os.path.join(cwd, start_path))
+            sconf['start_directory'] = start_path
 
-    if ('shell_command' in sconf and isinstance(sconf['shell_command'], basestring)):
+    if (
+        'shell_command' in sconf and
+        isinstance(sconf['shell_command'], string_types)
+    ):
         sconf['shell_command'] = [sconf['shell_command']]
-    # elif not 'windows' in sconf and not 'panes' in sconf and isinstance(sconf, basestring):  # probable pane
-        # logger.error(sconf)
-        # sconf = {'shell_command': [sconf]}
 
-    if ('shell_command_before' in sconf and isinstance(sconf['shell_command_before'], basestring)):
+    if (
+        'shell_command_before' in sconf and
+        isinstance(sconf['shell_command_before'], string_types)
+    ):
         sconf['shell_command_before'] = [sconf['shell_command_before']]
 
     # recurse into window and pane config items
@@ -178,45 +197,38 @@ def expand(sconf, cwd=None):
         ]
     elif 'panes' in sconf:
 
-        for p in sconf['panes']:
-            p_index = sconf['panes'].index(p)
+        for pconf in sconf['panes']:
+            p_index = sconf['panes'].index(pconf)
+            p = copy.deepcopy(pconf)
+            pconf = sconf['panes'][p_index] = {}
 
-            if not isinstance(p, dict) and not isinstance(p, list):  # probable pane
-                p = sconf['panes'][p_index] = {
+            if isinstance(p, string_types):
+                p = {
                     'shell_command': [p]
                 }
-
-            if isinstance (p, dict) and not len(p):
-                p = sconf['panes'][p_index] = {
+            elif not p:
+                p = {
                     'shell_command': []
                 }
 
-            if isinstance(p, basestring):
-
-                p = sconf['panes'][p_index] = {
-                    'shell_command': [p]
-                }
-
+            assert isinstance(p, dict)
+            assert 'shell_command' in p
             if 'shell_command' in p:
+                cmd = p['shell_command']
 
-                if isinstance(p['shell_command'], basestring):
-                    p = sconf['panes'][p_index] = {
-                        'shell_command': [p['shell_command']]
-                    }
+                if isinstance(p['shell_command'], string_types):
+                    cmd = [cmd]
 
-                if p['shell_command'] is None:
-                    p = sconf['panes'][p_index] = {
-                        'shell_command': []
-                    }
-                elif isinstance(p['shell_command'], list) and \
-                    len(p['shell_command']) == int(1) and (
-                        any(a in p['shell_command'] for a in [None, 'blank', 'pane']) or \
-                        p['shell_command'][0] is None
-                    ):
-                        p = sconf['panes'][p_index] = {
-                            'shell_command': []
-                        }
+                if not cmd or any(a == cmd for a in [None, 'blank', 'pane']):
+                    cmd = []
 
+                if isinstance(cmd, list) and len(cmd) == int(1):
+                    if any(a in cmd for a in [None, 'blank', 'pane']):
+                        cmd = []
+
+                p['shell_command'] = cmd
+
+            pconf.update(p)
         sconf['panes'] = [expand(pane) for pane in sconf['panes']]
 
     return sconf
@@ -253,27 +265,32 @@ def trickle(sconf):
             if not 'start_directory' in windowconfig:
                 windowconfig['start_directory'] = session_start_directory
             else:
-                if not any(windowconfig['start_directory'].startswith(a) for a in ['~', '/']):
-                    windowconfig['start_directory'] = os.path.join(
-                        session_start_directory, windowconfig['start_directory'])
+                if not any(
+                    windowconfig['start_directory'].startswith(a)
+                    for a in ['~', '/']
+                ):
+                    window_start_path = os.path.join(
+                        session_start_directory, windowconfig['start_directory']
+                    )
+                    windowconfig['start_directory'] = window_start_path
 
         for paneconfig in windowconfig['panes']:
             commands_before = []
 
             # Prepend shell_command_before to commands
             if 'shell_command_before' in sconf:
-                commands_before = sconf['shell_command_before']
+                commands_before.extend(sconf['shell_command_before'])
             if 'shell_command_before' in windowconfig:
                 commands_before.extend(windowconfig['shell_command_before'])
             if 'shell_command_before' in paneconfig:
                 commands_before.extend(paneconfig['shell_command_before'])
-            if 'shell_command' not in paneconfig:
-                paneconfig['shell_command'] = list()
 
-            if paneconfig['shell_command']:
+            if 'shell_command' in paneconfig:
                 commands_before.extend(paneconfig['shell_command'])
 
-            paneconfig['shell_command'] = commands_before
+            p_index = windowconfig['panes'].index(paneconfig)
+            windowconfig['panes'][p_index]['shell_command'] = commands_before
+            #paneconfig['shell_command'] = commands_before
 
     return sconf
 
@@ -327,12 +344,12 @@ def import_tmuxinator(sconf):
     if 'pre' in sconf and 'pre_window' in sconf:
         tmuxp_config['shell_command'] = sconf['pre']
 
-        if isinstance(sconf['pre'], basestring):
+        if isinstance(sconf['pre'], string_types):
             tmuxp_config['shell_command_before'] = [sconf['pre_window']]
         else:
             tmuxp_config['shell_command_before'] = sconf['pre_window']
     elif 'pre' in sconf:
-        if isinstance(sconf['pre'], basestring):
+        if isinstance(sconf['pre'], string_types):
             tmuxp_config['shell_command_before'] = [sconf['pre']]
         else:
             tmuxp_config['shell_command_before'] = sconf['pre']
@@ -351,7 +368,7 @@ def import_tmuxinator(sconf):
 
             windowdict['window_name'] = k
 
-            if isinstance(v, basestring) or v is None:
+            if isinstance(v, string_types) or v is None:
                 windowdict['panes'] = [v]
                 tmuxp_config['windows'].append(windowdict)
                 continue
