@@ -13,9 +13,11 @@ tmuxp helps you manage tmux workspaces.
 from __future__ import absolute_import, division, print_function, with_statement
 
 import pipes
+import logging
+
 from .window import Window
 from . import util, formats, exc
-import logging
+
 logger = logging.getLogger(__name__)
 
 
@@ -125,7 +127,8 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
     def new_window(self,
                    window_name=None,
                    start_directory=None,
-                   attach=True):
+                   attach=True,
+                   window_index=''):
         """Return :class:`Window` from ``$ tmux new-window``.
 
         .. note::
@@ -175,7 +178,8 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
             window_args += ('-n%s' % window_name,)
 
         window_args += (
-            '-t%s' % self.get('session_id'),
+            # empty string for window_index will use the first one available
+            '-t%s:%s' % (self.get('session_id'), window_index),
         )
 
         proc = self.tmux('new-window', *window_args)
@@ -331,7 +335,7 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
                 proc.stderr = proc.stderr[0]
             raise ValueError('tmux set-option stderr: %s' % proc.stderr)
 
-    def show_options(self, option=None):
+    def show_options(self, option=None, g=False):
         """Return a dict of options for the window.
 
         For familiarity with tmux, the option ``option`` param forwards to pick
@@ -339,15 +343,23 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
 
         :param option: optional. show a single option.
         :type option: string
+        :param g: Pass ``-g`` flag for global variable
+        :type g: bool
         :rtype: :py:obj:`dict`
 
         """
 
+        tmux_args = tuple()
+
+        if g:
+            tmux_args += ('-g',)
+
         if option:
-            return self.show_option(option)
+            return self.show_option(option, g=g)
         else:
+            tmux_args += ('show-options',)
             session_options = self.tmux(
-                'show-options'
+                *tmux_args
             ).stdout
 
         session_options = [tuple(item.split(' ')) for item in session_options]
@@ -360,7 +372,7 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
 
         return session_options
 
-    def show_option(self, option):
+    def show_option(self, option, g=False):
         """Return a list of options for the window.
 
         :todo: test and return True/False for on/off string
@@ -371,8 +383,13 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
 
         """
 
+        tmux_args = tuple()
+
+        if g:
+            tmux_args += ('-g',)
+
         window_option = self.tmux(
-            'show-options', option
+            'show-options', option, *tmux_args
         ).stdout
         window_option = [tuple(item.split(' ')) for item in window_option][0]
 
