@@ -1,16 +1,28 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp command line interface.
+
+tmuxp.tests.test_cli
+~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
 import shutil
-import kaptan
 import tempfile
+import logging
+
+import kaptan
+
 from .. import config, cli
 from ..util import tmux
 from .helpers import TestCase
 
-import logging
-
 logger = logging.getLogger(__name__)
 TMUXP_DIR = os.path.join(os.path.dirname(__file__), '.tmuxp')
 
