@@ -1,11 +1,22 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp Pane object.
+
+tmuxp.tests.test_pane
+~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
+
+import logging
 
 from . import t
 from .helpers import TmuxTestCase
 
-import logging
-
 logger = logging.getLogger(__name__)
 
 
@@ -22,12 +33,12 @@ class ResizeTest(TmuxTestCase):
         pane1_height = pane1['pane_height']
         pane2 = window.split_window()
 
-        pane1.resize_pane(height=7)
+        pane1.resize_pane(height=4)
         self.assertNotEqual(pane1['pane_height'], pane1_height)
-        self.assertEqual(int(pane1['pane_height']), 7)
+        self.assertEqual(int(pane1['pane_height']), 4)
 
-        pane1.resize_pane(height=9)
-        self.assertEqual(int(pane1['pane_height']), 9)
+        pane1.resize_pane(height=3)
+        self.assertEqual(int(pane1['pane_height']), 3)
 
     def test_set_height(self):
         window = self.session.new_window(window_name='test_set_height')
@@ -35,9 +46,9 @@ class ResizeTest(TmuxTestCase):
         pane1 = window.attached_pane()
         pane1_height = pane1['pane_height']
 
-        pane1.set_height(6)
+        pane1.set_height(2)
         self.assertNotEqual(pane1['pane_height'], pane1_height)
-        self.assertEqual(int(pane1['pane_height']), 6)
+        self.assertEqual(int(pane1['pane_height']), 2)
 
     def test_set_width(self):
         window = self.session.new_window(window_name='test_set_width')
@@ -47,8 +58,8 @@ class ResizeTest(TmuxTestCase):
         pane1 = window.attached_pane()
         pane1_width = pane1['pane_width']
 
-        pane1.set_width(25)
+        pane1.set_width(10)
         self.assertNotEqual(pane1['pane_width'], pane1_width)
-        self.assertEqual(int(pane1['pane_width']), 25)
+        self.assertEqual(int(pane1['pane_width']), 10)
 
         pane1.reset()
