@@ -1,31 +1,43 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp Session object.
+
+tmuxp.tests.test_session
+~~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 from random import randint
-from time import sleep
+import logging
+
 from .. import Session, Window, Pane
 from ..util import tmux
+
 from .helpers import TmuxTestCase, TEST_SESSION_PREFIX
 from . import t
 
-import logging
-
 logger = logging.getLogger(__name__)
 
 
 class SessionTest(TmuxTestCase):
 
     def test_has_session(self):
-        """Server.has_session returns True if has session_name exists"""
+        """Server.has_session returns True if has session_name exists."""
         self.assertTrue(t.has_session(self.TEST_SESSION_NAME))
         self.assertFalse(t.has_session('asdf2314324321'))
 
     def test_select_window(self):
-        """Session.select_window moves window"""
+        """Session.select_window moves window."""
         # get the current window_base_index, since different user tmux config
         # may start at 0 or 1, or whatever they want.
         window_base_index = int(
-            self.session.attached_window().get('window_index'))
+            self.session.attached_window().get('window_index')
+        )
 
         window = self.session.new_window(window_name='test_window')
         window_count = len(self.session._windows)
@@ -57,7 +69,7 @@ class SessionTest(TmuxTestCase):
             selected_window1.__dict__, selected_window2.__dict__)
 
     def test_select_window_returns_Window(self):
-        """Session.select_window returns Window object"""
+        """Session.select_window returns Window object."""
 
         window_count = len(self.session._windows)
         self.assertEqual(len(self.session._windows), window_count)
@@ -68,15 +80,15 @@ class SessionTest(TmuxTestCase):
             window_base_index), Window)
 
     def test_attached_window(self):
-        """Session.attached_window() returns Window"""
+        """Session.attached_window() returns Window."""
         self.assertIsInstance(self.session.attached_window(), Window)
 
     def test_attached_pane(self):
-        """Session.attached_pane() returns Pane"""
+        """Session.attached_pane() returns Pane."""
         self.assertIsInstance(self.session.attached_pane(), Pane)
 
     def test_session_rename(self):
-        """Session.rename_session renames session"""
+        """Session.rename_session renames session."""
         test_name = 'testingdis_sessname'
         self.session.rename_session(test_name)
         self.assertEqual(self.session.get('session_name'), test_name)
@@ -90,7 +102,7 @@ class SessionTest(TmuxTestCase):
 class SessionNewTest(TmuxTestCase):
 
     def test_new_session(self):
-        """Server.new_session creates new session"""
+        """Server.new_session creates new session."""
         new_session_name = TEST_SESSION_PREFIX + str(randint(0, 1337))
         new_session = t.new_session(session_name=new_session_name, detach=True)
 
@@ -107,8 +119,7 @@ class Options(TmuxTestCase):
         self.assertIsInstance(options, dict)
 
     def test_set_show_options_single(self):
-        """Set option then Session.show_options(key)
-        """
+        """Set option then Session.show_options(key)."""
 
         self.session.set_option('history-limit', 20)
         self.assertEqual(20, self.session.show_options('history-limit'))
@@ -119,8 +130,7 @@ class Options(TmuxTestCase):
         self.assertEqual(40, self.session.show_options()['history-limit'])
 
     def test_set_show_option(self):
-        """Set option then Session.show_option(key)
-        """
+        """Set option then Session.show_option(key)."""
         self.session.set_option('history-limit', 20)
         self.assertEqual(20, self.session.show_option('history-limit'))
 
@@ -129,6 +139,6 @@ class Options(TmuxTestCase):
         self.assertEqual(40, self.session.show_option('history-limit'))
 
     def test_set_option_bad(self):
-        """Session.set_option raises ValueError for bad option key"""
+        """Session.set_option raises ValueError for bad option key."""
         with self.assertRaises(ValueError):
             self.session.set_option('afewewfew', 43)
