@@ -1,13 +1,26 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp workspacebuilder.
+
+tmuxp.tests.test_workspacebuilder
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
 import sys
 import logging
 import time
+
 import kaptan
+
 from .. import Window, config, exc
-from ..util import unicode
+from .._compat import text_type
 from ..workspacebuilder import WorkspaceBuilder
 from .helpers import TmuxTestCase
 
@@ -32,7 +45,7 @@ class TwoPaneTest(TmuxTestCase):
       window_name: editor
     - panes:
       - shell_command:
-        - tail -F /var/log/syslog
+        - tail | echo 'hi'
       window_name: logging
     - window_name: test
       panes:
@@ -111,29 +124,37 @@ class FocusAndPaneIndexTest(TmuxTestCase):
       focus: true
       panes:
       - shell_command:
-        - vim
+        - cd ~
       - shell_command:
-        - echo "hey"
+        - cd /usr
+        focus: true
       - shell_command:
+        - cd ~
         - echo "moo"
         - top
-        focus: true
     - window_name: window 2
       panes:
       - shell_command:
-        - vim
-        rocus: true
+        - top
+        focus: true
       - shell_command:
         - echo "hey"
       - shell_command:
         - echo "moo"
-
+    - window_name: window 3
+      panes:
+      - shell_command: cd /
+        focus: true
+      - pane
+      - pane
     """
 
-    def test_split_windows(self):
+    def test_focus_pane_index(self):
         s = self.session
         sconfig = kaptan.Kaptan(handler='yaml')
         sconfig = sconfig.import_config(self.yaml_config).get()
+        sconfig = config.expand(sconfig)
+        sconfig = config.trickle(sconfig)
 
         builder = WorkspaceBuilder(sconf=sconfig)
 
@@ -144,9 +165,9 @@ class FocusAndPaneIndexTest(TmuxTestCase):
             'focused window'
         )
 
-        pane_base_index = self.session.attached_window().show_window_option(
-            'pane-base-index'
-        )
+        pane_base_index = int(self.session.attached_window().show_window_option(
+            'pane-base-index', g=True
+        ))
 
         if not pane_base_index:
             pane_base_index = 0
@@ -161,6 +182,38 @@ class FocusAndPaneIndexTest(TmuxTestCase):
         pane_indexes_should_be = [pane_base_index + x for x in range(0, 3)]
         self.assertListEqual(pane_indexes_should_be, pane_base_indexes)
 
+        w = self.session.attached_window()
+
+        self.assertNotEqual(w.get('window_name'), 'man')
+
+        pane_path = '/usr'
+        for i in range(60):
+            p = w.attached_pane()
+            p.server._update_panes()
+            if p.get('pane_current_path') == pane_path:
+                break
+            time.sleep(.2)
+
+        self.assertEqual(p.get('pane_current_path'), pane_path)
+
+        proc = self.session.tmux('show-option', '-gv', 'base-index')
+        base_index = int(proc.stdout[0])
+        self.session.server._update_windows()
+
+        window3 = self.session.findWhere({'window_index': str(base_index + 2)})
+        self.assertIsInstance(window3, Window)
+
+        p = None
+        pane_path = '/'
+        for i in range(60):
+            p = window3.attached_pane()
+            p.server._update_panes()
+            if p.get('pane_current_path') == pane_path:
+                break
+            time.sleep(.2)
+
+        self.assertEqual(p.get('pane_current_path'), pane_path)
+
 
 class WindowOptions(TmuxTestCase):
 
@@ -170,15 +223,11 @@ class WindowOptions(TmuxTestCase):
     windows:
     - layout: main-horizontal
       options:
-        main-pane-height: 30
+        main-pane-height: 5
       panes:
-      - shell_command:
-        - vim
-        start_directory: '~'
-      - shell_command:
-        - echo "hey"
-      - shell_command:
-        - echo "moo"
+      - pane
+      - pane
+      - pane
       window_name: editor
     """
 
@@ -186,6 +235,7 @@ class WindowOptions(TmuxTestCase):
         s = self.session
         sconfig = kaptan.Kaptan(handler='yaml')
         sconfig = sconfig.import_config(self.yaml_config).get()
+        sconfig = config.expand(sconfig)
 
         builder = WorkspaceBuilder(sconf=sconfig)
 
@@ -198,7 +248,7 @@ class WindowOptions(TmuxTestCase):
                 p = p
                 self.assertEqual(len(s._windows), window_count)
             self.assertIsInstance(w, Window)
-            self.assertEqual(w.show_window_option('main-pane-height'), 30)
+            self.assertEqual(w.show_window_option('main-pane-height'), 5)
 
             self.assertEqual(len(s._windows), window_count)
             window_count += 1
@@ -225,7 +275,7 @@ class WindowAutomaticRename(TmuxTestCase):
     """
 
     def test_automatic_rename_option(self):
-        """ with option automatic-rename: on. """
+        """With option automatic-rename: on."""
         s = self.session
         sconfig = kaptan.Kaptan(handler='yaml')
         sconfig = sconfig.import_config(self.yaml_config).get()
@@ -251,31 +301,33 @@ class WindowAutomaticRename(TmuxTestCase):
         self.assertNotEqual(s.get('session_name'), 'tmuxp')
         w = s.windows[0]
 
-        for i in range(30):
+        for i in range(60):
+            self.session.server._update_windows()
             if w.get('window_name') != 'man':
                 break
-            time.sleep(.5)
+            time.sleep(.2)
 
         self.assertNotEqual(w.get('window_name'), 'man')
 
         pane_base_index = w.show_window_option('pane-base-index', g=True)
         w.select_pane(pane_base_index)
 
-        for i in range(30):
+        for i in range(60):
             self.session.server._update_windows()
             if w.get('window_name') == 'man':
                 break
-            time.sleep(.5)
+            time.sleep(.25)
 
-        self.assertEqual(w.get('window_name'), unicode('man'))
+        self.assertEqual(w.get('window_name'), text_type('man'))
 
         w.select_pane('-D')
-        for i in range(30):
+        for i in range(60):
+            self.session.server._update_windows()
             if w['window_name'] != 'man':
                 break
-            time.sleep(.5)
+            time.sleep(.25)
 
-        self.assertEqual(w.get('window_name'), unicode('man'))
+        self.assertNotEqual(w.get('window_name'), text_type('man'))
 
 
 class BlankPaneTest(TmuxTestCase):
@@ -288,25 +340,32 @@ class BlankPaneTest(TmuxTestCase):
 
         test_config = kaptan.Kaptan().import_config(self.yaml_config_file).get()
         test_config = config.expand(test_config)
+        # for window in test_config['windows']:
+            # window['layout'] = 'tiled'
         builder = WorkspaceBuilder(sconf=test_config)
         builder.build(session=self.session)
 
-        window1 = self.session.findWhere({'window_name': 'Blank pane test'})
-        self.assertEqual(len(window1._panes), 6)
+        self.assertEqual(self.session, builder.session)
 
-        window1 = self.session.findWhere({'window_name': 'Empty string (return)'})
+        window1 = self.session.findWhere({'window_name': 'Blank pane test'})
         self.assertEqual(len(window1._panes), 3)
 
-        self.assertEqual(self.session, builder.session)
+        window2 = self.session.findWhere({'window_name': 'More blank panes'})
+        self.assertEqual(len(window2._panes), 3)
+
+        window3 = self.session.findWhere(
+            {'window_name': 'Empty string (return)'}
+        )
+        self.assertEqual(len(window3._panes), 3)
 
 
 class StartDirectoryTest(TmuxTestCase):
     yaml_config = """
     session_name: sampleconfig
-    start_directory: '/var'
+    start_directory: '/usr'
     windows:
-    - window_name: supposed to be /var/log
-      start_directory: '/var/log'
+    - window_name: supposed to be /usr/bin
+      start_directory: '/usr/bin'
       layout: main-horizontal
       options:
           main-pane-height: 50
@@ -357,7 +416,7 @@ class StartDirectoryTest(TmuxTestCase):
         builder.build(session=self.session)
 
         assert(self.session == builder.session)
-        for path in ['/var/log', '/dev/', '/var/', os.getcwd()]:
+        for path in ['/usr/bin', '/dev/', '/usr/', os.getcwd()]:
             for window in self.session.windows:
                 for p in window.panes:
                     self.assertTrue(p.get('pane_start_path', path))
@@ -377,21 +436,22 @@ class PaneOrderingTest(TmuxTestCase):
     windows:
     - options:
       - automatic_rename: on
+      layout: tiled
       panes:
-      - cd /var/log
-      - cd /sys
+      - cd /usr/bin
+      - cd /usr
       - cd /sbin
-      - cd /tmp
+      - cd /home
     """
 
     def test_pane_order(self):
 
         # test order of `panes` (and pane_index) above aganist pane_dirs
         pane_paths = [
-            '/var/log',
-            '/sys',
+            '/usr/bin',
+            '/usr',
             '/sbin',
-            '/tmp'
+            '/home'
         ]
         s = self.session
         sconfig = kaptan.Kaptan(handler='yaml')
@@ -415,8 +475,6 @@ class PaneOrderingTest(TmuxTestCase):
             window_count += 1
 
         for w in self.session.windows:
-            import time
-            time.sleep(1)
             pane_base_index = w.show_window_option('pane-base-index', g=True)
             for p_index, p in enumerate(w.list_panes(), start=pane_base_index):
                 self.assertEqual(int(p_index), int(p.get('pane_index')))
@@ -425,10 +483,47 @@ class PaneOrderingTest(TmuxTestCase):
                 # at 0 since python list.
                 pane_path = pane_paths[p_index - pane_base_index]
 
-                for i in range(30):
+                for i in range(60):
                     p.server._update_panes()
                     if p.get('pane_current_path') == pane_path:
                         break
-                    time.sleep(.5)
+                    time.sleep(.2)
 
                 self.assertEqual(p.get('pane_current_path'), pane_path)
+
+
+class WindowIndexTest(TmuxTestCase):
+    yaml_config = """
+    session_name: sampleconfig
+    windows:
+    - window_name: zero
+      panes:
+      - echo 'zero'
+    - window_name: five
+      panes:
+      - echo 'five'
+      window_index: 5
+    - window_name: one
+      panes:
+      - echo 'one'
+    """
+
+    def test_window_index(self):
+        proc = self.session.tmux('show-option', '-gv', 'base-index')
+        base_index = int(proc.stdout[0])
+        name_index_map = {
+            'zero': 0 + base_index,
+            'one': 1 + base_index,
+            'five': 5,
+        }
+
+        sconfig = kaptan.Kaptan(handler='yaml')
+        sconfig = sconfig.import_config(self.yaml_config).get()
+        sconfig = config.expand(sconfig)
+        sconfig = config.trickle(sconfig)
+
+        builder = WorkspaceBuilder(sconf=sconfig)
+
+        for window, wconf in builder.iter_create_windows(self.session):
+            expected_index = name_index_map[window['window_name']]
+            self.assertEqual(int(window['window_index']), expected_index)
