@@ -1,11 +1,23 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, with_statement
+"""Test for tmuxp workspacefreezer.
+
+tmuxp.tests.test_workspacefreezer
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: Copyright 2013 Tony Narlock.
+:license: BSD, see LICENSE for details
+
+"""
+
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
-import sys
 import logging
 import time
+
 import kaptan
+
 from .. import Window, config, exc
 from ..workspacebuilder import WorkspaceBuilder, freeze
 from .helpers import TmuxTestCase
@@ -33,8 +45,8 @@ class FreezeTest(TmuxTestCase):
       window_name: editor
     - panes:
       - shell_command:
-        - tail -F /var/log/syslog
-        start_directory: /var/log
+        - pane
+        start_directory: /usr/bin
       window_name: logging
     - window_name: test
       panes:
@@ -76,6 +88,3 @@ class FreezeTest(TmuxTestCase):
             default_flow_style=False,
             safe=True
         )
-
-        #logger.error(json)
-        #logger.error(yaml)
