@@ -10,19 +10,20 @@ tmuxp helps you manage tmux workspaces.
 :license: BSD, see LICENSE for details
 
 """
-from __future__ import absolute_import, division, print_function, with_statement
-from __future__ import unicode_literals
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
-from distutils.version import StrictVersion
 import unittest
 import collections
 import subprocess
 import os
 import sys
-from . import exc
-
 import logging
 
+from distutils.version import StrictVersion
+
+from . import exc
+
 logger = logging.getLogger(__name__)
 
 PY2 = sys.version_info[0] == 2
@@ -37,7 +38,9 @@ class tmux(object):
         proc = tmux('new-session', '-s%' % 'my session')
 
         if proc.stderr:
-            raise exc.TmuxpException('Command: %s returned error: %s' % (proc.cmd, proc.stderr))
+            raise exc.TmuxpException(
+                'Command: %s returned error: %s' % (proc.cmd, proc.stderr)
+            )
 
         print('tmux command returned %s' % proc.stdout)
 
@@ -113,6 +116,7 @@ class TmuxMappingObject(collections.MutableMapping):
         self.dirty = True
 
     def keys(self):
+        """Return list of keys."""
         return self._TMUX.keys()
 
     def __iter__(self):
@@ -153,7 +157,10 @@ class TmuxRelationalObject(object):
         .. _underscore.js: http://underscorejs.org/
 
         """
-        return self.where(attrs)[0] or None
+        try:
+            return self.where(attrs)[0]
+        except IndexError:
+            return None
 
     def where(self, attrs, first=False):
         """Return objects matching child objects properties.
@@ -185,7 +192,9 @@ class TmuxRelationalObject(object):
             return list(filter(by, self.children))
 
     def getById(self, id):
-        """Return object based on `.get()`_ from `backbone.js`_.
+        """Return object based on ``childIdAttribute``.
+
+        Based on `.get()`_ from `backbone.js`_.
 
         .. _backbone.js: http://backbonejs.org/
         .. _.get(): http://backbonejs.org/#Collection-get
@@ -281,35 +290,13 @@ def oh_my_zsh_auto_title():
     if 'SHELL' in os.environ and 'zsh' in os.environ.get('SHELL'):
         if os.path.exists(os.path.expanduser('~/.oh-my-zsh')):
             # oh-my-zsh exists
-            if 'DISABLE_AUTO_TITLE' not in os.environ or os.environ.get('DISABLE_AUTO_TITLE') == "false":
+            if (
+                'DISABLE_AUTO_TITLE' not in os.environ or
+                os.environ.get('DISABLE_AUTO_TITLE') == "false"
+            ):
                 print('Please set:\n\n'
                       '\texport DISABLE_AUTO_TITLE = \'true\'\n\n'
                       'in ~/.zshrc or where your zsh profile is stored.\n'
                       'Remember the "export" at the beginning!\n\n'
                       'Then create a new shell or type:\n\n'
                       '\t$ source ~/.zshrc')
-
-
-# http://www.rfk.id.au/blog/entry/preparing-pyenchant-for-python-3/
-try:
-    unicode = unicode
-except NameError:
-    # 'unicode' is undefined, must be Python 3
-    str = str
-    unicode = str
-    bytes = bytes
-    basestring = (str, bytes)
-else:
-    # 'unicode' exists, must be Python 2
-    str = str
-    unicode = unicode
-    bytes = str
-    basestring = basestring
-
-
-if not PY2:
-    input = input
-    from string import ascii_lowercase
-else:
-    input = raw_input
-    from string import lower as ascii_lowercase
