@@ -10,13 +10,14 @@ tmuxp helps you manage tmux workspaces.
 :license: BSD, see LICENSE for details
 
 """
-from __future__ import absolute_import, division, print_function, with_statement
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import pipes
-from .pane import Pane
+import logging
 
 from . import util, formats, exc
-import logging
+from .pane import Pane
 
 logger = logging.getLogger(__name__)
 
@@ -141,7 +142,7 @@ class Window(util.TmuxMappingObject, util.TmuxRelationalObject):
         )
 
         if process.stderr:
-            if isinstance(process.stderr, list) and len(process.stderr) == int(1):
+            if isinstance(process.stderr, list) and len(process.stderr):
                 process.stderr = process.stderr[0]
             raise ValueError(
                 'tmux set-window-option -t%s:%s %s %s\n' % (
@@ -226,14 +227,12 @@ class Window(util.TmuxMappingObject, util.TmuxRelationalObject):
         return window_option[1]
 
     def rename_window(self, new_name):
-
         """Return :class:`Window` object ``$ tmux rename-window <new_name>``.
 
         :param new_name: name of the window
         :type new_name: string
 
         """
-        # new_name = pipes.quote(new_name)
 
         import shlex
         lex = shlex.shlex(new_name)
@@ -297,7 +296,8 @@ class Window(util.TmuxMappingObject, util.TmuxRelationalObject):
         :rtype: :class:`Window`
 
         """
-        return self.session.select_window(self.get('window_id'))
+        target = '%s:%s' % (self.get('session_id'), self.get('window_index')),
+        return self.session.select_window(target)
 
     def select_pane(self, target_pane):
         """Return selected :class:`Pane` through ``$ tmux select-pane``.
@@ -310,7 +310,11 @@ class Window(util.TmuxMappingObject, util.TmuxRelationalObject):
         """
 
         if target_pane in ['-l', '-U', '-D', '-L', '-R']:
-            proc = self.tmux('select-pane', '-t%s' % self.get('window_id'), target_pane)
+            proc = self.tmux(
+                'select-pane',
+                '-t%s' % self.get('window_id'),
+                target_pane
+            )
         else:
             proc = self.tmux('select-pane', '-t%s' % target_pane)
 
