@@ -11,9 +11,12 @@ tmuxp helps you manage tmux workspaces.
 
 """
 
-from __future__ import absolute_import, division, print_function, with_statement
-import logging
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
+
 import os
+import logging
+
 from . import exc, config, Window, Pane, Session, Server
 
 logger = logging.getLogger(__name__)
@@ -29,7 +32,7 @@ class WorkspaceBuilder(object):
     The normal phase of loading is:
 
         1.  :term:`kaptan` imports json/yaml/ini. ``.get()`` returns python
-        :class:`dict`::
+            :class:`dict`::
 
                 import kaptan
                 sconf = kaptan.Kaptan(handler='yaml')
@@ -133,18 +136,27 @@ class WorkspaceBuilder(object):
         assert(isinstance(session, Session))
 
         focus = None
+
         for w, wconf in self.iter_create_windows(session):
             assert(isinstance(w, Window))
-            for p in self.iter_create_panes(w, wconf):
+
+            focus_pane = None
+            for p, pconf in self.iter_create_panes(w, wconf):
                 assert(isinstance(p, Pane))
                 p = p
 
                 if 'layout' in wconf:
                     w.select_layout(wconf['layout'])
 
+                if 'focus' in pconf and pconf['focus']:
+                    focus_pane = p
+
             if 'focus' in wconf and wconf['focus']:
                 focus = w
 
+            if focus_pane:
+                focus_pane.select_pane()
+
         if focus:
             focus.select_window()
 
@@ -157,7 +169,7 @@ class WorkspaceBuilder(object):
         Applies ``window_options`` to window.
 
         :param session: :class:`Session` from the config
-        :rtype: :class:`Window`
+        :rtype: tuple(:class:`Window`, ``wconf``)
 
         """
         for i, wconf in enumerate(self.sconf['windows'], start=1):
@@ -175,7 +187,8 @@ class WorkspaceBuilder(object):
                 window_name=window_name,
                 start_directory=wconf[
                     'start_directory'] if 'start_directory' in wconf else None,
-                attach=False  # do not move to the new window
+                attach=False,  # do not move to the new window
+                window_index=wconf.get('window_index', ''),
             )
 
             if i == int(1) and w1:  # if first window, use window 1
@@ -187,7 +200,7 @@ class WorkspaceBuilder(object):
                     w.set_window_option(key, val)
 
             if 'focus' in wconf and wconf['focus']:
-                s.select_window(w['window_id'])
+                w.select_window()
 
             s.server._update_windows()
 
@@ -202,7 +215,7 @@ class WorkspaceBuilder(object):
         :type w: :class:`Window`
         :param wconf: config section for window
         :type wconf: :py:obj:`dict`
-        :rtype: :class:`Pane`
+        :rtype: tuple(:class:`Pane`, ``pconf``)
 
         """
         assert(isinstance(w, Window))
@@ -210,18 +223,18 @@ class WorkspaceBuilder(object):
         pane_base_index = int(w.show_window_option('pane-base-index', g=True))
 
         for pindex, pconf in enumerate(wconf['panes'], start=pane_base_index):
-            if pindex != int(pane_base_index):
+
+            if pindex == int(pane_base_index):
+                p = w.attached_pane()
+
+            else:
                 p = w.split_window(
                     attach=True,
                     #target=w.list_panes()[-1].get('pane_index')
                 )
-                assert(isinstance(p, Pane))
-                assert int(p.get('pane_index')) == int(pane_base_index + pindex)
-            else:
-                p = w.attached_pane()
-                assert(isinstance(p, Pane))
-                assert int(p.get('pane_index')) == int(pane_base_index)
 
+            assert(isinstance(p, Pane))
+            assert(int(p.get('pane_index')) == int(pindex))
             if 'layout' in wconf:
                 w.select_layout(wconf['layout'])
 
@@ -233,7 +246,7 @@ class WorkspaceBuilder(object):
 
             w.server._update_panes()
 
-            yield p
+            yield p, pconf
 
 
 def freeze(session):
